@@ -1,6 +1,6 @@
 package SADI::Simple::Utils;
 {
-  $SADI::Simple::Utils::VERSION = '0.008';
+  $SADI::Simple::Utils::VERSION = '0.010';
 }
 
 use strict;
@@ -80,6 +80,9 @@ sub serialize_model
 
     if (grep($_ eq $mime_type, @N3_MIME_TYPES)) {
         $serializer = RDF::Trine::Serializer->new('turtle');
+    } elsif (lc($mime_type) eq "application/n-quads") {
+    	$serializer = RDF::Trine::Serializer->new( 'nquads');
+    	$self->add_nanopub_metadata($model);
     } else {
         $serializer = RDF::Trine::Serializer->new('rdfxml');
     }
@@ -105,4 +108,43 @@ sub get_standard_content_type
     return $standard_content_type;
 }
 
+
+sub add_nanopub_metadata {
+	my ($self) = @_;
+
+#
+#@prefix : <http://www.example.org/mynanopub/>.
+#@prefix ex: <http://www.example.org/>.
+#@prefix np: <http://www.nanopub.org/nschema#>.
+#@prefix dct: <http://purl.org/dc/terms/>.
+#@prefix go: <http://purl.obolibrary.org/obo/>.
+#@prefix up: <http://purl.uniprot.org/core/> .
+#@prefix pav: <http://swan.mindinformatics.org/ontologies/1.2/pav/>
+#@prefix xsd: <http://www.w3.org/2001/XMLSchema#>.
+#{
+#:nanopub1 np:hasAssertion :G1;
+#np:hasProvenance :G2;
+#np:hasSupporting :G3.
+#:G1 a np:Assertion.
+#:G2 a np:Provenance.
+#:G3 a np:Supporting.
+#}
+#:G1 {
+#<http://purl.uniprot.org/uniprot/O76074>
+#up:classifiedWith go:GO_0000287, go:GO_0005737, go:GO_0007165,
+#go:GO_0008270, go:GO_0009187, go:GO_0030553.
+#}
+#:G2 {
+#:nanopub1 pav:versionNumber "1.1"
+#:nanopub1 pav:previousVersion "1.0".
+#:nanopub1 dct:created "2009-09-03"^^xsd:date.
+#:nanopub1 dct:creator ex:JohnSmith.
+#:nanopub1 dct:rightsHolder ex:SomeOrganization.
+#:nanopub1 up:citation <http://bio2rdf.org/medline:99320215>.
+#}
+
+
+}
+
+
 1;
